@@ -5,8 +5,8 @@ from numba.core.ccallback import CFunc
 from numba.core.typing import Signature
 from numba.types import CPointer, intc, void, voidptr
 
-from slumba.numbaext import get_sqlite3_result_function, make_arg_tuple
-from slumba.sqlite import sqlite3_result_null
+from .numbaext import get_sqlite3_result_function, make_arg_tuple
+from .sqlite import sqlite3_result_null
 
 
 def sqlite_udf(
@@ -28,8 +28,10 @@ def sqlite_udf(
     def wrapper(func: Callable) -> CFunc:
         compiled_func = njit(signature, nogil=nogil, **njit_kwargs)(func)
 
-        @cfunc(void(voidptr, intc, CPointer(voidptr)))
-        def scalar(ctx, argc, argv):  # pragma: no cover
+        @cfunc(void(voidptr, intc, CPointer(voidptr)))  # type: ignore[misc]
+        def scalar(  # type: ignore[no-untyped-def]
+            ctx, argc: int, argv
+        ):  # pragma: no cover
             args = make_arg_tuple(compiled_func, argv)
             result = compiled_func(*args)
             if result is None:
